==> aws-sdk-cpp-kinesis-1.11.480-1.0-i486.pkg.tar.zst: usr/include/aws/kinesisanalyticsv2/model/InputParallelism.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/kinesisanalyticsv2/KinesisAnalyticsV2_EXPORTS.h>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace KinesisAnalyticsV2
{
namespace Model
{

  /**
   * <p>For a SQL-based Kinesis Data Analytics application, describes the number of
   * in-application streams to create for a given streaming source. </p><p><h3>See
   * Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/kinesisanalyticsv2-2018-05-23/InputParallelism">AWS
   * API Reference</a></p>
   */
  class InputParallelism
  {
  public:
    AWS_KINESISANALYTICSV2_API InputParallelism();
    AWS_KINESISANALYTICSV2_API InputParallelism(Aws::Utils::Json::JsonView jsonValue);
    AWS_KINESISANALYTICSV2_API InputParallelism& operator=(Aws::Utils::Json::JsonView jsonValue);
    AWS_KINESISANALYTICSV2_API Aws::Utils::Json::JsonValue Jsonize() const;


    ///@{
    /**
     * <p>The number of in-application streams to create.</p>
     */
    inline int GetCount() const{ return m_count; }
    inline bool CountHasBeenSet() const { return m_countHasBeenSet; }
    inline void SetCount(int value) { m_countHasBeenSet = true; m_count = value; }
    inline InputParallelism& WithCount(int value) { SetCount(value); return *this;}
    ///@}
  private:

    int m_count;
    bool m_countHasBeenSet = false;
  };

} // namespace Model
} // namespace KinesisAnalyticsV2
} // namespace Aws

==> aws-sdk-cpp-kinesis-1.11.536-1.0-i486.pkg.tar.zst: usr/include/aws/kinesisanalyticsv2/model/InputParallelism.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/kinesisanalyticsv2/KinesisAnalyticsV2_EXPORTS.h>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace KinesisAnalyticsV2
{
namespace Model
{

  /**
   * <p>For a SQL-based Kinesis Data Analytics application, describes the number of
   * in-application streams to create for a given streaming source. </p><p><h3>See
   * Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/kinesisanalyticsv2-2018-05-23/InputParallelism">AWS
   * API Reference</a></p>
   */
  class InputParallelism
  {
  public:
    AWS_KINESISANALYTICSV2_API InputParallelism() = default;
    AWS_KINESISANALYTICSV2_API InputParallelism(Aws::Utils::Json::JsonView jsonValue);
    AWS_KINESISANALYTICSV2_API InputParallelism& operator=(Aws::Utils::Json::JsonView jsonValue);
    AWS_KINESISANALYTICSV2_API Aws::Utils::Json::JsonValue Jsonize() const;


    ///@{
    /**
     * <p>The number of in-application streams to create.</p>
     */
    inline int GetCount() const { return m_count; }
    inline bool CountHasBeenSet() const { return m_countHasBeenSet; }
    inline void SetCount(int value) { m_countHasBeenSet = true; m_count = value; }
    inline InputParallelism& WithCount(int value) { SetCount(value); return *this;}
    ///@}
  private:

    int m_count{0};
    bool m_countHasBeenSet = false;
  };

} // namespace Model
} // namespace KinesisAnalyticsV2
} // namespace Aws
